==> constructorio-ui-quizzes-1.4.0.tgz: package/lib/mjs/hooks/usePropsGetters/useSelectInputProps.js <==
import { useState, useCallback, useEffect, useRef } from 'react';
import { QuestionTypes } from '../../components/CioQuiz/actions';
// eslint-disable-next-line max-params
export default function useSelectInputProps(quizAnswerChanged, nextQuestion, currentQuestionData, answerInputs) {
    const type = currentQuestionData?.type;
    const hasImages = currentQuestionData?.options?.some((option) => option.images);
    const [selected, setSelected] = useState({});
    const singleSelectClicked = useRef({});
    const toggleIdSelected = useCallback((id) => {
        if (type === QuestionTypes.SingleSelect) {
            singleSelectClicked.current = true;
            setSelected({ [id]: true });
        }
        else if (type === QuestionTypes.MultipleSelect) {
            if (selected[id]) {
                const newState = { ...selected };
                delete newState[id];
                setSelected(newState);
            }
            else {
                setSelected({ ...selected, [id]: true });
            }
        }
    }, [selected, type]);
    const onOptionKeyDown = (event, id) => {
        if (event?.key === ' ' || event?.key === 'Enter') {
            toggleIdSelected(id);
        }
    };
    // Update component local state
    useEffect(() => {
        if (currentQuestionData?.type) {
            const nextQuestionId = currentQuestionData.id;
            const currentAnswer = answerInputs?.[nextQuestionId];
            const prevSelected = {};
            if (Array.isArray(currentAnswer?.value)) {
                currentAnswer?.value?.forEach((answer) => {
                    prevSelected[Number(answer)] = true;
                    setSelected(prevSelected);
                });
            }
        }
        singleSelectClicked.current = false;
        return function clearState() {
            setSelected({});
        };
        // eslint-disable-next-line react-hooks/exhaustive-deps
    }, [currentQuestionData?.id]);
    // Update global state
    useEffect(() => {
        if (currentQuestionData?.type === 'multiple' || currentQuestionData?.type === 'single') {
            const selectedAnswers = Object.keys(selected).filter((key) => selected[Number(key)]);
            quizAnswerChanged(selectedAnswers);
        }
    }, [selected, currentQuestionData?.id, currentQuestionData?.type, quizAnswerChanged]);
    // Go to next question only every time answerInputs (answers input state) changes...
    // and it's a singleSelectQuestion and user has just clicked on an option
    useEffect(() => {
        if (currentQuestionData?.type === 'single' && singleSelectClicked.current) {
            nextQuestion();
        }
        // eslint-disable-next-line react-hooks/exhaustive-deps
    }, [answerInputs]);
    const getSelectInputProps = useCallback((option) => ({
        className: `${!hasImages ? 'cio-question-option-container-text-only' : 'cio-question-option-container'} ${selected[option.id] ? 'selected' : ''}`,
        onClick: () => {
            toggleIdSelected(option.id);
        },
        onKeyDown: (event) => {
            onOptionKeyDown(event, option.id);
        },
        role: 'button',
        tabIndex: 0,
        key: option.id,
    }), 
    // eslint-disable-next-line react-hooks/exhaustive-deps
    [currentQuestionData?.id, selected]);
    return getSelectInputProps;
}

==> constructorio-ui-quizzes-1.17.13.tgz: package/lib/mjs/hooks/usePropsGetters/useSelectInputProps.js <==
import { useState, useCallback, useEffect, useRef } from 'react';
import { QuestionTypes } from '../../components/CioQuiz/actions';
// eslint-disable-next-line max-params
export default function useSelectInputProps(quizAnswerChanged, nextQuestion, currentQuestionData, answerInputs) {
    const type = currentQuestionData?.type;
    const hasImages = currentQuestionData?.options?.some((option) => option.images);
    const [selected, setSelected] = useState({});
    const singleSelectClicked = useRef({});
    const toggleIdSelected = useCallback((id) => {
        if (type === QuestionTypes.SingleSelect) {
            singleSelectClicked.current = true;
            setSelected({ [id]: true });
        }
        else if (type === QuestionTypes.MultipleSelect) {
            if (selected[id]) {
                const newState = { ...selected };
                delete newState[id];
                setSelected(newState);
            }
            else {
                setSelected({ ...selected, [id]: true });
            }
        }
    }, [selected, type]);
    const onOptionKeyDown = (event, id) => {
        if (event?.key === ' ' || event?.key === 'Enter') {
            toggleIdSelected(id);
        }
    };
    // Update component local state
    useEffect(() => {
        if (currentQuestionData?.type) {
            const nextQuestionId = currentQuestionData.id;
            const currentAnswer = answerInputs?.[nextQuestionId];
            const prevSelected = {};
            if (Array.isArray(currentAnswer?.value)) {
                currentAnswer?.value?.forEach((answer) => {
                    prevSelected[Number(answer.id)] = true;
                    setSelected(prevSelected);
                });
            }
        }
        singleSelectClicked.current = false;
        return function clearState() {
            setSelected({});
        };
        // eslint-disable-next-line react-hooks/exhaustive-deps
    }, [currentQuestionData?.id]);
    // Update global state
    useEffect(() => {
        if (currentQuestionData?.type === 'multiple' || currentQuestionData?.type === 'single') {
            const selectedAnswers = currentQuestionData?.options
                ?.filter((opt) => selected[Number(opt.id)])
                ?.map((opt) => ({ id: opt.id, value: opt.value }));
            quizAnswerChanged(selectedAnswers);
        }
    }, [
        selected,
        currentQuestionData?.id,
        currentQuestionData?.type,
        currentQuestionData?.options,
        quizAnswerChanged,
    ]);
    // Go to next question only every time answerInputs (answers input state) changes...
    // and it's a singleSelectQuestion and user has just clicked on an option
    useEffect(() => {
        if (currentQuestionData?.type === 'single' && singleSelectClicked.current) {
            nextQuestion();
        }
        // eslint-disable-next-line react-hooks/exhaustive-deps
    }, [answerInputs]);
    const getSelectInputProps = useCallback((option) => ({
        className: `${!hasImages ? 'cio-question-option-container-text-only' : 'cio-question-option-container'} ${selected[option.id] ? 'selected' : ''}`,
        onClick: () => {
            toggleIdSelected(option.id);
        },
        onKeyDown: (event) => {
            onOptionKeyDown(event, option.id);
        },
        role: 'button',
        tabIndex: 0,
        key: option.id,
    }), 
    // eslint-disable-next-line react-hooks/exhaustive-deps
    [currentQuestionData?.id, selected]);
    return getSelectInputProps;
}
